ContentEncoder<Content extends Object> class abstract

An interface to encode Content into a text or binary format.

Constructors

ContentEncoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writer → Content
Returns the Content writer.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
The binary representation of content already written to this encoder.
toString() → String
The text representation of content already written to this encoder.
override
toText() → String
The text representation of content already written to this encoder.

Operators

operator ==(Object other) → bool
The equality operator.
inherited