Geom enum

An enum for geometry types.

Geometry types introduced above are based on the Simple Feature Access - Part 1: Common Architecture standard by The Open Geospatial Consortium.

The types are also compatible with Well-known text representation of geometry.

Inheritance
Available extensions

Values

point → const Geom

The type for the POINT geometry.

const Geom(wktName: 'POINT', geoJsonName: 'Point', wkbId2D: 1)
lineString → const Geom

The type for the LINESTRING geometry.

const Geom(wktName: 'LINESTRING', geoJsonName: 'LineString', wkbId2D: 2)
polygon → const Geom

The type for the POLYGON geometry.

const Geom(wktName: 'POLYGON', geoJsonName: 'Polygon', wkbId2D: 3)
multiPoint → const Geom

The type for the MULTIPOINT geometry.

const Geom(wktName: 'MULTIPOINT', geoJsonName: 'MultiPoint', wkbId2D: 4)
multiLineString → const Geom

The type for the MULTILINESTRING geometry.

const Geom(wktName: 'MULTILINESTRING', geoJsonName: 'MultiLineString', wkbId2D: 5)
multiPolygon → const Geom

The type for the MULTIPOLYGON geometry.

const Geom(wktName: 'MULTIPOLYGON', geoJsonName: 'MultiPolygon', wkbId2D: 6)
geometryCollection → const Geom

The type for the GEOMETRYCOLLECTION geometry.

const Geom(wktName: 'GEOMETRYCOLLECTION', geoJsonName: 'GeometryCollection', wkbId2D: 7)

Properties

geoJsonName → String
The GeoJSON type for the geometry type, ie. Point for the point type.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isCollection → bool
True for the collection of other geometries (geometryCollection).
no setter
isMulti → bool
True for multi geometries (multiPoint, multiLineString, multiPolygon).
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wkbId2D → int
The WKB type for the (2-dimensional) geometry, ie. 1 for the point type.
final
wktName → String
The WKT name for the geometry type, ie. POINT for the point type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
wkbId(Coords coordinateType) → int
The WKB type for this geometry type and the given coordinateType.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromWkbId(int id) → Geom
Selects a Geom enum based on the WKB type id.

Constants

values → const List<Geom>
A constant List of the values in this enum, in order of their declaration.