GeometryCollection<E extends Geometry> class

A geometry collection.

Inheritance
Annotations
  • @immutable

Constructors

GeometryCollection(Iterable<E> geometries)
Creates GeometryCollection from geometries.

Properties

bounds → Bounds<Point<num>>?
The bounds for this object (could be calculated if not explicitely set).
no setter
boundsExplicit → Bounds<Point<num>>?
The explicit bounds for this object when available.
no setter
dimension → int
The topological dimension of this geometry.
no setteroverride
geometries → BoundedSeries<E>
All geometries for this geometry collection.
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
True if this geometry is considered empty without data or coordinates.
no setteroverride
isNotEmpty → bool
True if this geometry is NOT considered empty without data or coordinates.
no setterinherited
onePoint → Point<num>?
Returns one of points contained by this geometry if it's not empty.
no setteroverride
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
typeGeom → Geom
The type of this geometry.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
project<R extends Point<num>>(Projection projection, {required CreatePosition<R> to}) → GeometryCollection<Geometry>
Returns a new geometry with all points projected using projection.
override
toString() → String
A string representation of this object.
override
toStringAs({TextWriterFormat<GeometryContent> format = DefaultFormat.geometry, int? decimals}) → String
A string representation of this geometry, with format applied.
inherited
transform(TransformPosition transform) → GeometryCollection<E>
Returns a new geometry with all points transformed using transform.
override
writeTo(GeometryContent writer) → void
Writes this geometry object to writer.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited