PointFactory<T extends Point<num>> class abstract

An interface to create Point instances of the type T.

Inheritance
Implementers

Constructors

PointFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMeasured → bool
True if a measure value is available (or the m coordinate for a position).
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

newFrom(Iterable<num> coords, {int? offset, int? length}) → T
Creates a new point instance of a type compatible with this object.
override
newWith({num x = 0.0, num y = 0.0, num? z, num? m}) → T
Creates a new point instance of a type compatible with this object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited