ProjectedPoint<C extends num> class abstract

A read-only projected (or cartesian) point with x, y, z and m.

Coordinate values of type C are either num (allowing double or int), double or int.

Inheritance
Implementers

Constructors

ProjectedPoint()
Default const constructor to allow extending this abstract class.
const

Properties

bounds → Bounds<Point<num>>?
The bounds for this object (could be calculated if not explicitely set).
no setterinherited
boundsExplicit → Bounds<Point<num>>?
The explicit bounds for this object when available.
no setterinherited
coordinateDimension → int
The number of coordinate values (2, 3 or 4).
no setterinherited
dimension → int
The topological dimension of this geometry.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
is3D → bool
True for 3D positions (with z or elevation coordinate).
no setterinherited
isEmpty → bool
True if this geometry is considered empty without data or coordinates.
no setterinherited
isGeographic → bool
True for geographic coordinates (with longitude and latitude).
no setteroverride
isMeasured → bool
True if a measure value is available (or the m coordinate for a position).
no setterinherited
isNotEmpty → bool
True if this geometry is NOT considered empty without data or coordinates.
no setterinherited
m → C
The m ("measure") coordinate value. Returns zero if not available.
no setterinherited
onePoint → Point<num>?
Returns one of points contained by this geometry if it's not empty.
no setterinherited
optM → C?
The m ("measure") coordinate optionally. Returns null if not available.
no setterinherited
optZ → C?
The z coordinate value optionally. Returns null if not available.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spatialDimension → int
The number of spatial coordinate values (2 for 2D or 3 for 3D).
no setterinherited
type → Coords
The coordinate type.
no setterinherited
typeGeom → Geom
The type of this geometry.
no setterinherited
values → List<C>
Returns coordinate values of this point as a fixed length list.
no setterinherited
x → C
The x coordinate value.
no setterinherited
y → C
The y coordinate value.
no setterinherited
z → C
The z coordinate value. Returns zero if not available.
no setterinherited

Methods

copyTo<R extends Position>(CreatePosition<R> factory) → R
Copies this position to a new position created by the factory.
inherited
copyWith({num? x, num? y, num? z, num? m}) → ProjectedPoint<num>
Copies this point with optional x, y, z and m overriding values.
override
equals2D(Position other, {num? toleranceHoriz}) → bool
True if this position equals with other by testing 2D coordinates only.
inherited
equals3D(Position other, {num? toleranceHoriz, num? toleranceVert}) → bool
True if this position equals with other by testing 3D coordinates only.
inherited
newFrom(Iterable<num> coords, {int? offset, int? length}) → ProjectedPoint<num>
Creates a new point instance of a type compatible with this object.
override
newWith({num x = 0.0, num y = 0.0, num? z, num? m}) → ProjectedPoint<num>
Creates a new point instance of a type compatible with this object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
project<R extends Point<num>>(Projection projection, {required CreatePosition<R> to}) → R
Returns a new point projected from this point using projection.
inherited
toString() → String
A string representation of this object.
inherited
toStringAs({TextWriterFormat<GeometryContent> format = DefaultFormat.geometry, int? decimals}) → String
A string representation of this geometry, with format applied.
inherited
transform(TransformPosition transform) → ProjectedPoint<num>
Returns a new point transformed from this point using transform.
override
valuesAsString({String delimiter = ',', int? decimals}) → String
A string representation of coordinate values separated by delimiter.
inherited
writeTo(SimpleGeometryContent writer) → void
Writes this geometry object to writer.
inherited
writeValues(StringSink buffer, {String delimiter = ',', int? decimals}) → void
Writes coordinate values to buffer separated by delimiter.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](int i) → C
A coordinate value by the coordinate axis index i.
inherited